# Changelog

<!-- version list -->

## v1.1.0 (2025-10-14)

### Features

- Implement field selectors API
  ([`e099dbe`](https://github.com/Promptly-Technologies-LLC/etielle/commit/e099dbe9dda503fc745370dcfe9850918641ac35))


## v1.0.6 (2025-10-14)

### Bug Fixes

- Configure pyproject version stamping
  ([`49c4e07`](https://github.com/Promptly-Technologies-LLC/etielle/commit/49c4e07af4cf72c446c3847399abe776e515ab85))


## v1.0.5 (2025-10-14)

### Bug Fixes

- Make release dependent on test
  ([`b377958`](https://github.com/Promptly-Technologies-LLC/etielle/commit/b37795886a41674c677bc13e2df676fe42effc6f))


## v1.0.4 (2025-10-14)

### Bug Fixes

- Correctly use PyPi env for publish job
  ([`2dd6cea`](https://github.com/Promptly-Technologies-LLC/etielle/commit/2dd6cea8ff3fd99a5ac64d627721bcdac394750a))


## v1.0.3 (2025-10-14)

### Bug Fixes

- Run build in PSR container
  ([`6c359c6`](https://github.com/Promptly-Technologies-LLC/etielle/commit/6c359c6bc281118068fe1b41a6f5e8db4d8cad87))


## v1.0.2 (2025-10-14)

### Bug Fixes

- Restore build step
  ([`4250642`](https://github.com/Promptly-Technologies-LLC/etielle/commit/42506424365d86a321acc044e0363840da0dc6f3))


## v1.0.1 (2025-10-14)

### Bug Fixes

- Gate artifact upload
  ([`5e5bda1`](https://github.com/Promptly-Technologies-LLC/etielle/commit/5e5bda1ee36397b3913ab3a1cbc58b28e5d3f458))


## v1.0.0 (2025-10-14)

### Bug Fixes

- Actions-compliant root path
  ([`251d553`](https://github.com/Promptly-Technologies-LLC/etielle/commit/251d5530f61aaef988f0ed23bcf312e85f3a822c))

- Add missing semantic release config
  ([`f6235d4`](https://github.com/Promptly-Technologies-LLC/etielle/commit/f6235d449d76a8ae9d6788d494f08d44a612fd10))

- Semantic release version mismatch
  ([`3dbf9a0`](https://github.com/Promptly-Technologies-LLC/etielle/commit/3dbf9a0559a47e59efbf23d9ed4a935422283647))

- Use semantic release's built-in committer
  ([`6681c31`](https://github.com/Promptly-Technologies-LLC/etielle/commit/6681c31c30c29f835998ec1a77d39d752e64c52a))
